pub enum SeedsExpr {
List(Punctuated<Expr, Comma>),
Expr(Box<Expr>),
}Expand description
Seeds can be written as a literal slice ([ a, b ]) or any
expression that produces &[&[u8]] at run time.
Variants
List(Punctuated<Expr, Comma>)
Example: [ b"prefix".as_ref(), key.as_ref() ]
Expr(Box<Expr>)
Example: pda_seeds(key)
Implementations
Sourceimpl SeedsExpr
impl SeedsExpr
Sourcepub fn pop(&mut self) -> Option<Pair<Expr, Comma>>
pub fn pop(&mut self) -> Option<Pair<Expr, Comma>>
Mirrors Punctuated::pop: removes and returns the last element and its
trailing punctuation when this is the List variant. For the Expr variant,
which represents a single non-list seed expression, returns None because
there is no list to pop from.
pub fn push_value(&mut self, value: Expr)
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Mirrors Punctuated::push_value: pushes a value without punctuation onto
the underlying list when this is the List variant. No-op for the Expr
variant.